2026-10-09 APP 2.0.0-beta48 has been released !
This is mainly a bug fix release for the reported bugs in beta47. In addition it has a significant User Interface performance improvement noticable when you need to process 1000s of images in APP.
2026-10-03 APP 2.0.0-beta47 has been released !
This is a very big release... many code optimizations/rewrites, many parts of APP are much faster and more precise, especially star analysis and registration are much faster ! Big mosaics will go much faster 🙂
And we introduce a new preview filter, which includes the new Adaptive Deep Sky Stretch and a General Levels Stretch, this has been long over due. The old preview filter (the panel on the right side to stretch and preview your data) has not been updated for a couple of years and it is a critical part of any APP session.
Adaptive Deep Sky Stretch or ADSS is a much more intuitive stretch algorithm. It is also color preserving (which is a great new addition in itself ! ) which means that the highlights are no longer bleached, color is maintained from the linear data while stretching. You can simply stretch your data using the sky background level and signal width sliders which work much easier and more intuitive. You no longer need to fiddle with the old complicated sliders with zoom buttons. All the zoom buttons for the sliders are made redundant. And you can enter slider values in the slider value fields yourself. I will make a youtube video in the coming days to explain and fully introduce ADSS. Once the video is ready, it will be highlighted on the forum.
RGB Combine upgrade !. The RGB Combine Tool has been rewritten mostly. The tool is faster and easier to use and most importantly, the Luminance slider to inject a luminance channel or channels into the RGB composite is now working correctly. It no longer bleaches the RGB colors. Combined with the new ADSS preview, you will get much better and easier great composites with great color! I will also explain this in a new youtube video.
I have saved about 300 (about 5 hours) frames after calibration, registration and normalization. I am trying to integrate these frames without having to go through analyze stars AGAIN. My thinking is that I’ve followed the normal process except going to the integrate step. I load the processed frames as lights so the integrate step will show frames to be processed.
I tried to directly go from importing lights Setting the individual step parameters and then integrating without saving the normalized lights. But when I try this method the program will eventually show as no longer executing and is “frozen”. Even after waiting a second day the program will not resume.
What am I doing wrong?!?! Previous versions with this number of lights would always process. I am running version 1.079 currently.
Thom
Currently APP doesn't see the frames as already been processed and needs to built up a star map to have a proper idea of the data. This is something we'd like to improve upon in a future release, but yes APP needs to analyze the stars at the start.
Vincent,
Thanks for the quick reply!!
OK, I’m glad to know it’s a known problem. The Analyze Stars, and normalization processing did proceed much more quickly, with processed frames. And the integration result looked just fine.
Thanks,
Thom